#include <qpixmap.h>
#include <qtimer.h>

#include "kwindowinfo.h"
#include "kwindowinfo.moc"

static const int UNSPECIFIED_TIMEOUT = -1;
static const int DEFAULT_MESSAGE_TIMEOUT = 3000;

KWindowInfo::KWindowInfo( QWidget *parent, const char *name )
    : QObject( parent, name ), win( parent ), autoDel( false )
{
}

KWindowInfo::~KWindowInfo()
{
}

void KWindowInfo::showMessage( QWidget *window, const QString &text, int timeout )
{
    KWindowInfo *info = new KWindowInfo( window );
    info->autoDel = true;
    info->message( text, timeout );
}

void KWindowInfo::showMessage( QWidget *window, const QString &text, const QPixmap &pix, int timeout )
{
    KWindowInfo *info = new KWindowInfo( window );
    info->autoDel = true;
    info->message( text, pix, timeout );
}

void KWindowInfo::message( const QString &text )
{
    message( text, QPixmap(), UNSPECIFIED_TIMEOUT );
}

void KWindowInfo::message( const QString &text, const QPixmap &pix )
{
    message( text, pix, UNSPECIFIED_TIMEOUT );
}

void KWindowInfo::message( const QString &text, int timeout )
{
    message( text, QPixmap(), timeout );
}

void KWindowInfo::message( const QString &text, const QPixmap &pix, int timeout )
{
    QPixmap icon;
    if ( pix.isNull() )
	icon.load( "bell.png" );
    else
	icon = pix;

    save();
    win->setCaption( text );
    win->setIcon( icon );

    if ( timeout <= 0 )
	timeout = DEFAULT_MESSAGE_TIMEOUT;
    QTimer::singleShot( timeout, this, SLOT( restore() ) );
}

void KWindowInfo::save()
{
    oldText = win->caption();

    const QPixmap *px = win->icon();
    if ( px )
	oldIcon = *px;
    else
	oldIcon.resize( 0, 0 );
}

void KWindowInfo::restore()
{
    win->setCaption( oldText );
    win->setIcon( oldIcon );

    if ( autoDel )
	delete this;
}





