/*
 *   copyright            : (C) 2001-2002 by Richard Moore
 *   email                : rich@kde.org
 */

#include <qhbox.h>
#include <qvbox.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qpixmap.h>
#include <qpushbutton.h>
#include <qtextedit.h>

#include <kdialog.h>
#include <kglobalsettings.h>
#include <klistview.h>
#include <klocale.h>
#include <knotifyclient.h>

#include "kpassivepopup.h"
#include "kwindowinfo.h"
#include "loggertray.h"

#include "logtracker.h"

LogTracker::LogTracker(QWidget *parent, const char *name) : QVBox(parent, name)
{
    setMargin( KDialog::marginHint() );
    setSpacing( KDialog::spacingHint() );

    QPixmap px;
    px.load( "lo16-action-wizard.png" );
    setIcon( px );
    setCaption( "Demo of Passive Popups and Window Messages" );

    QLabel *l = new QLabel( i18n("<b>Passive Popup Test</b>"), this );
    QFont f = l->font();
    f.setPointSize( 22 );
    l->setFont( f );
    l->setBackgroundColor( KGlobalSettings::alternateBackgroundColor() );
    l->setAlignment( AlignCenter );
    l->setFrameStyle( QFrame::Box| QFrame::Plain );
    l->setLineWidth( 2 );

    QHBox *box = new QHBox( this );
    box->setSpacing( KDialog::spacingHint() );

    QVBox *vb = new QVBox( box );
    vb->setMargin( KDialog::marginHint() );
    vb->setSpacing( KDialog::spacingHint() );

    l = new QLabel( i18n("Passive Popups"), vb );
    f = l->font();
    f.setPointSize( 16 );
    l->setFont( f );
    l->setBackgroundColor( KGlobalSettings::alternateBackgroundColor() );
    l->setAlignment( AlignCenter );
    l->setFrameStyle( QFrame::Box| QFrame::Plain );
    l->setLineWidth( 2 );
    l->setSizePolicy( QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed) );

    QPushButton *pb = new QPushButton( i18n("&Message"), vb );
    QPushButton *pb2 = new QPushButton( i18n("&Titled Message"), vb );
    QPushButton *pb3 = new QPushButton( i18n("&Big Icon Message"), vb );
    QPushButton *pb4 = new QPushButton( i18n("&Small Icon Message"), vb );
    QPushButton *pb5 = new QPushButton( i18n("&Custom Message"), vb );
    QPushButton *pb6 = new QPushButton( i18n("&KNotify Event"), vb );
    QPushButton *pb7 = new QPushButton( i18n("KNotify &User Event"), vb );
    QWidget *spacer = new QWidget( vb );
    spacer->setSizePolicy( QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding) );

    QVBox *vb3 = new QVBox( box );
    vb3->setMargin( KDialog::marginHint() );
    vb3->setSpacing( KDialog::spacingHint() );

    l = new QLabel( i18n("KWin Messages"), vb3 );
    f = l->font();
    f.setPointSize( 16 );
    l->setFont( f );
    l->setBackgroundColor( KGlobalSettings::alternateBackgroundColor() );
    l->setAlignment( AlignCenter );
    l->setFrameStyle( QFrame::Box| QFrame::Plain );
    l->setLineWidth( 2 );
    l->setSizePolicy( QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed) );

    QPushButton *pb8 = new QPushButton( i18n("&WM Icon/Title"), vb3 );
    QPushButton *pb9 = new QPushButton( i18n("WM Text Message (static)"), vb3 );
    QPushButton *pb10 = new QPushButton( i18n("WM Icon Message (static)"), vb3 );
    QPushButton *pb11 = new QPushButton( i18n("KNotify WM Message"), vb3 );
    spacer = new QWidget( vb3 );
    spacer->setSizePolicy( QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding) );

    connect( pb, SIGNAL( clicked() ), SLOT( showPopup() ) );
    connect( pb2, SIGNAL( clicked() ), SLOT( showPopup2() ) );
    connect( pb3, SIGNAL( clicked() ), SLOT( showPopup3() ) );
    connect( pb4, SIGNAL( clicked() ), SLOT( showPopup4() ) );
    connect( pb5, SIGNAL( clicked() ), SLOT( showPopup5() ) );
    connect( pb6, SIGNAL( clicked() ), SLOT( knotifyEvent() ) );
    connect( pb7, SIGNAL( clicked() ), SLOT( knotifyPassivePopup() ) );
    connect( pb8, SIGNAL( clicked() ), SLOT( showWindowMessage() ) );
    connect( pb9, SIGNAL( clicked() ), SLOT( showWindowMessageTextStatic() ) );
    connect( pb10, SIGNAL( clicked() ), SLOT( showWindowMessageStatic() ) );
    connect( pb11, SIGNAL( clicked() ), SLOT( knotifyWindowMessage() ) );

    QVBox *vb2 = new QVBox( box );
    vb2->setMargin( KDialog::marginHint() );
    vb2->setSpacing( KDialog::spacingHint() );

    l = new QLabel( i18n("Message Contents"), vb2 );
    f = l->font();
    f.setPointSize( 16 );
    l->setFont( f );
    l->setBackgroundColor( KGlobalSettings::alternateBackgroundColor() );
    l->setAlignment( AlignCenter );
    l->setFrameStyle( QFrame::Box| QFrame::Plain );
    l->setLineWidth( 2 );

    QHBox *tb = new QHBox( vb2 );
    tb->setSpacing( KDialog::spacingHint() );
    l = new QLabel( i18n("<b>Title</b>"), tb );
    title = new QLineEdit( i18n("Message Title"), tb );

    QHBox *tb2 = new QHBox( vb2 );
    tb2->setSpacing( KDialog::spacingHint() );

    l = new QLabel( i18n("<b>Text</b>"), tb2 );
    text = new QTextEdit( tb2 );
    text->setTextFormat( PlainText );
    text->setText( i18n("The main <b>message</b> text") );

    addSysTray();
}

LogTracker::~LogTracker()
{
}

void LogTracker::showPopup()
{
    KPassivePopup::message( text->text(), this );
}

void LogTracker::showPopup2()
{
    KPassivePopup::message( title->text(), text->text(), this );
}

void LogTracker::showPopup3()
{
    QPixmap px;
    px.load( "lo32-app-logtracker.png" );
    KPassivePopup::message( title->text(), text->text(), px, this );
}

void LogTracker::showPopup4()
{
    QPixmap px;
    px.load( "lo16-app-logtracker.png" );
    KPassivePopup::message( title->text(), text->text(), px, this );
}

void LogTracker::showPopup5()
{
    showCustom( this );
}

void LogTracker::knotifyEvent()
{
    KNotifyClient::event("demoevent");
}

void LogTracker::knotifyPassivePopup()
{
    KNotifyClient::userEvent( text->text(), KNotifyClient::PassivePopup, KNotifyClient::Error );
}

void LogTracker::showWindowMessage()
{
    QPixmap px;
    px.load( "lo16-app-logtracker.png" );

    KWindowInfo *info = new KWindowInfo( this );
    info->message( text->text(), px );
}

void LogTracker::showWindowMessageTextStatic()
{
    KWindowInfo::showMessage( this, text->text(), 1000 );
}

void LogTracker::showWindowMessageStatic()
{
    QPixmap px;
    px.load( "lo16-app-logtracker.png" );
    KWindowInfo::showMessage( this, text->text(), px, 1000 );
}

void LogTracker::knotifyWindowMessage()
{
    KNotifyClient::userEvent( text->text(), KNotifyClient::WindowInfo, KNotifyClient::Error );
}

void LogTracker::showCustom( QWidget *parent )
{
    KPassivePopup *pop = new KPassivePopup( parent );

    QVBox *vb = new QVBox( pop );
    vb->setSpacing( KDialog::spacingHint() );
    
    QHBox *tbox = new QHBox( vb );
    tbox->setSpacing( KDialog::spacingHint() );
    QLabel *pl = new QLabel( tbox );
    QPixmap px;
    px.load( "lo32-app-logtracker.png" );
    pl->setPixmap( px );
    new QLabel( i18n("<qt><h3>What do you think?</h3><hr/>" \
		     "Would you agree that this is pretty cool stuff?</qt>"),
		tbox );

    QHBox *box = new QHBox( vb );
    box->setSpacing( KDialog::spacingHint() );
    new QPushButton( i18n("Yes"), box );
    new QPushButton( i18n("No"), box );

    pop->setView( vb );
    pop->show();
}

void LogTracker::addSysTray()
{
    LoggerTray *lt = new LoggerTray( this );

    QPixmap px;
    px.load( "lo16-app-logtracker.png" );
    lt->setPixmap( px );
    lt->show();
}

